# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spounge.polykey.v2 import auth_pb2 as polykey_dot_v2_dot_auth__pb2
from spounge.polykey.v2 import batch_operations_pb2 as polykey_dot_v2_dot_batch__operations__pb2
from spounge.polykey.v2 import metrics_pb2 as polykey_dot_v2_dot_metrics__pb2
from spounge.polykey.v2 import single_operations_pb2 as polykey_dot_v2_dot_single__operations__pb2
from spounge.polykey.v2 import stream_operations_pb2 as polykey_dot_v2_dot_stream__operations__pb2


class PolykeyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/polykey.v2.PolykeyService/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_metrics__pb2.HealthCheckResponse.FromString,
                _registered_method=True)
        self.GetKey = channel.unary_unary(
                '/polykey.v2.PolykeyService/GetKey',
                request_serializer=polykey_dot_v2_dot_single__operations__pb2.GetKeyRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_single__operations__pb2.GetKeyResponse.FromString,
                _registered_method=True)
        self.ListKeys = channel.unary_unary(
                '/polykey.v2.PolykeyService/ListKeys',
                request_serializer=polykey_dot_v2_dot_single__operations__pb2.ListKeysRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_single__operations__pb2.ListKeysResponse.FromString,
                _registered_method=True)
        self.CreateKey = channel.unary_unary(
                '/polykey.v2.PolykeyService/CreateKey',
                request_serializer=polykey_dot_v2_dot_single__operations__pb2.CreateKeyRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_single__operations__pb2.CreateKeyResponse.FromString,
                _registered_method=True)
        self.RotateKey = channel.unary_unary(
                '/polykey.v2.PolykeyService/RotateKey',
                request_serializer=polykey_dot_v2_dot_single__operations__pb2.RotateKeyRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_single__operations__pb2.RotateKeyResponse.FromString,
                _registered_method=True)
        self.RevokeKey = channel.unary_unary(
                '/polykey.v2.PolykeyService/RevokeKey',
                request_serializer=polykey_dot_v2_dot_single__operations__pb2.RevokeKeyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.UpdateKeyMetadata = channel.unary_unary(
                '/polykey.v2.PolykeyService/UpdateKeyMetadata',
                request_serializer=polykey_dot_v2_dot_single__operations__pb2.UpdateKeyMetadataRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetKeyMetadata = channel.unary_unary(
                '/polykey.v2.PolykeyService/GetKeyMetadata',
                request_serializer=polykey_dot_v2_dot_single__operations__pb2.GetKeyMetadataRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_single__operations__pb2.GetKeyMetadataResponse.FromString,
                _registered_method=True)
        self.BatchGetKeys = channel.unary_unary(
                '/polykey.v2.PolykeyService/BatchGetKeys',
                request_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeysRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeysResponse.FromString,
                _registered_method=True)
        self.BatchCreateKeys = channel.unary_unary(
                '/polykey.v2.PolykeyService/BatchCreateKeys',
                request_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchCreateKeysRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchCreateKeysResponse.FromString,
                _registered_method=True)
        self.BatchRotateKeys = channel.unary_unary(
                '/polykey.v2.PolykeyService/BatchRotateKeys',
                request_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchRotateKeysRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchRotateKeysResponse.FromString,
                _registered_method=True)
        self.BatchRevokeKeys = channel.unary_unary(
                '/polykey.v2.PolykeyService/BatchRevokeKeys',
                request_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchRevokeKeysRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchRevokeKeysResponse.FromString,
                _registered_method=True)
        self.BatchUpdateKeyMetadata = channel.unary_unary(
                '/polykey.v2.PolykeyService/BatchUpdateKeyMetadata',
                request_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchUpdateKeyMetadataRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchUpdateKeyMetadataResponse.FromString,
                _registered_method=True)
        self.BatchGetKeyMetadata = channel.unary_unary(
                '/polykey.v2.PolykeyService/BatchGetKeyMetadata',
                request_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeyMetadataRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeyMetadataResponse.FromString,
                _registered_method=True)
        self.StreamGetKeys = channel.unary_stream(
                '/polykey.v2.PolykeyService/StreamGetKeys',
                request_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeysRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeysResponse.FromString,
                _registered_method=True)
        self.StreamCreateKeys = channel.stream_stream(
                '/polykey.v2.PolykeyService/StreamCreateKeys',
                request_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamCreateKeysRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamCreateKeysResponse.FromString,
                _registered_method=True)
        self.StreamRotateKeys = channel.stream_stream(
                '/polykey.v2.PolykeyService/StreamRotateKeys',
                request_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamRotateKeysRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamRotateKeysResponse.FromString,
                _registered_method=True)
        self.StreamRevokeKeys = channel.stream_stream(
                '/polykey.v2.PolykeyService/StreamRevokeKeys',
                request_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamRevokeKeysRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamRevokeKeysResponse.FromString,
                _registered_method=True)
        self.StreamUpdateKeyMetadata = channel.stream_stream(
                '/polykey.v2.PolykeyService/StreamUpdateKeyMetadata',
                request_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamUpdateKeyMetadataRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamUpdateKeyMetadataResponse.FromString,
                _registered_method=True)
        self.StreamGetKeyMetadata = channel.stream_stream(
                '/polykey.v2.PolykeyService/StreamGetKeyMetadata',
                request_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeyMetadataRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeyMetadataResponse.FromString,
                _registered_method=True)
        self.Authenticate = channel.unary_unary(
                '/polykey.v2.PolykeyService/Authenticate',
                request_serializer=polykey_dot_v2_dot_auth__pb2.AuthenticateRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_auth__pb2.AuthenticateResponse.FromString,
                _registered_method=True)
        self.RefreshToken = channel.unary_unary(
                '/polykey.v2.PolykeyService/RefreshToken',
                request_serializer=polykey_dot_v2_dot_auth__pb2.RefreshTokenRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_auth__pb2.RefreshTokenResponse.FromString,
                _registered_method=True)
        self.RevokeToken = channel.unary_unary(
                '/polykey.v2.PolykeyService/RevokeToken',
                request_serializer=polykey_dot_v2_dot_auth__pb2.RevokeTokenRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_auth__pb2.RevokeTokenResponse.FromString,
                _registered_method=True)


class PolykeyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKey(self, request, context):
        """1-5, few nodes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RotateKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateKeyMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKeyMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetKeys(self, request, context):
        """Batch operations (5-50 keys)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchCreateKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchRotateKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchRevokeKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchUpdateKeyMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetKeyMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamGetKeys(self, request, context):
        """Streaming operations (50+ keys) unlikely right now, but in-case
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamCreateKeys(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamRotateKeys(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamRevokeKeys(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamUpdateKeyMetadata(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamGetKeyMetadata(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Authenticate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PolykeyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=polykey_dot_v2_dot_metrics__pb2.HealthCheckResponse.SerializeToString,
            ),
            'GetKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKey,
                    request_deserializer=polykey_dot_v2_dot_single__operations__pb2.GetKeyRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_single__operations__pb2.GetKeyResponse.SerializeToString,
            ),
            'ListKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKeys,
                    request_deserializer=polykey_dot_v2_dot_single__operations__pb2.ListKeysRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_single__operations__pb2.ListKeysResponse.SerializeToString,
            ),
            'CreateKey': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateKey,
                    request_deserializer=polykey_dot_v2_dot_single__operations__pb2.CreateKeyRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_single__operations__pb2.CreateKeyResponse.SerializeToString,
            ),
            'RotateKey': grpc.unary_unary_rpc_method_handler(
                    servicer.RotateKey,
                    request_deserializer=polykey_dot_v2_dot_single__operations__pb2.RotateKeyRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_single__operations__pb2.RotateKeyResponse.SerializeToString,
            ),
            'RevokeKey': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeKey,
                    request_deserializer=polykey_dot_v2_dot_single__operations__pb2.RevokeKeyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateKeyMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateKeyMetadata,
                    request_deserializer=polykey_dot_v2_dot_single__operations__pb2.UpdateKeyMetadataRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetKeyMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKeyMetadata,
                    request_deserializer=polykey_dot_v2_dot_single__operations__pb2.GetKeyMetadataRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_single__operations__pb2.GetKeyMetadataResponse.SerializeToString,
            ),
            'BatchGetKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetKeys,
                    request_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeysRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeysResponse.SerializeToString,
            ),
            'BatchCreateKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchCreateKeys,
                    request_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchCreateKeysRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchCreateKeysResponse.SerializeToString,
            ),
            'BatchRotateKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchRotateKeys,
                    request_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchRotateKeysRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchRotateKeysResponse.SerializeToString,
            ),
            'BatchRevokeKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchRevokeKeys,
                    request_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchRevokeKeysRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchRevokeKeysResponse.SerializeToString,
            ),
            'BatchUpdateKeyMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchUpdateKeyMetadata,
                    request_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchUpdateKeyMetadataRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchUpdateKeyMetadataResponse.SerializeToString,
            ),
            'BatchGetKeyMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetKeyMetadata,
                    request_deserializer=polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeyMetadataRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeyMetadataResponse.SerializeToString,
            ),
            'StreamGetKeys': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamGetKeys,
                    request_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeysRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeysResponse.SerializeToString,
            ),
            'StreamCreateKeys': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamCreateKeys,
                    request_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamCreateKeysRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamCreateKeysResponse.SerializeToString,
            ),
            'StreamRotateKeys': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamRotateKeys,
                    request_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamRotateKeysRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamRotateKeysResponse.SerializeToString,
            ),
            'StreamRevokeKeys': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamRevokeKeys,
                    request_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamRevokeKeysRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamRevokeKeysResponse.SerializeToString,
            ),
            'StreamUpdateKeyMetadata': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamUpdateKeyMetadata,
                    request_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamUpdateKeyMetadataRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamUpdateKeyMetadataResponse.SerializeToString,
            ),
            'StreamGetKeyMetadata': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamGetKeyMetadata,
                    request_deserializer=polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeyMetadataRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeyMetadataResponse.SerializeToString,
            ),
            'Authenticate': grpc.unary_unary_rpc_method_handler(
                    servicer.Authenticate,
                    request_deserializer=polykey_dot_v2_dot_auth__pb2.AuthenticateRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_auth__pb2.AuthenticateResponse.SerializeToString,
            ),
            'RefreshToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshToken,
                    request_deserializer=polykey_dot_v2_dot_auth__pb2.RefreshTokenRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_auth__pb2.RefreshTokenResponse.SerializeToString,
            ),
            'RevokeToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeToken,
                    request_deserializer=polykey_dot_v2_dot_auth__pb2.RevokeTokenRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_auth__pb2.RevokeTokenResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'polykey.v2.PolykeyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('polykey.v2.PolykeyService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PolykeyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            polykey_dot_v2_dot_metrics__pb2.HealthCheckResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/GetKey',
            polykey_dot_v2_dot_single__operations__pb2.GetKeyRequest.SerializeToString,
            polykey_dot_v2_dot_single__operations__pb2.GetKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/ListKeys',
            polykey_dot_v2_dot_single__operations__pb2.ListKeysRequest.SerializeToString,
            polykey_dot_v2_dot_single__operations__pb2.ListKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/CreateKey',
            polykey_dot_v2_dot_single__operations__pb2.CreateKeyRequest.SerializeToString,
            polykey_dot_v2_dot_single__operations__pb2.CreateKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RotateKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/RotateKey',
            polykey_dot_v2_dot_single__operations__pb2.RotateKeyRequest.SerializeToString,
            polykey_dot_v2_dot_single__operations__pb2.RotateKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RevokeKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/RevokeKey',
            polykey_dot_v2_dot_single__operations__pb2.RevokeKeyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateKeyMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/UpdateKeyMetadata',
            polykey_dot_v2_dot_single__operations__pb2.UpdateKeyMetadataRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetKeyMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/GetKeyMetadata',
            polykey_dot_v2_dot_single__operations__pb2.GetKeyMetadataRequest.SerializeToString,
            polykey_dot_v2_dot_single__operations__pb2.GetKeyMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchGetKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/BatchGetKeys',
            polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeysRequest.SerializeToString,
            polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchCreateKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/BatchCreateKeys',
            polykey_dot_v2_dot_batch__operations__pb2.BatchCreateKeysRequest.SerializeToString,
            polykey_dot_v2_dot_batch__operations__pb2.BatchCreateKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchRotateKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/BatchRotateKeys',
            polykey_dot_v2_dot_batch__operations__pb2.BatchRotateKeysRequest.SerializeToString,
            polykey_dot_v2_dot_batch__operations__pb2.BatchRotateKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchRevokeKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/BatchRevokeKeys',
            polykey_dot_v2_dot_batch__operations__pb2.BatchRevokeKeysRequest.SerializeToString,
            polykey_dot_v2_dot_batch__operations__pb2.BatchRevokeKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchUpdateKeyMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/BatchUpdateKeyMetadata',
            polykey_dot_v2_dot_batch__operations__pb2.BatchUpdateKeyMetadataRequest.SerializeToString,
            polykey_dot_v2_dot_batch__operations__pb2.BatchUpdateKeyMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchGetKeyMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/BatchGetKeyMetadata',
            polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeyMetadataRequest.SerializeToString,
            polykey_dot_v2_dot_batch__operations__pb2.BatchGetKeyMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamGetKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/polykey.v2.PolykeyService/StreamGetKeys',
            polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeysRequest.SerializeToString,
            polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamCreateKeys(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/polykey.v2.PolykeyService/StreamCreateKeys',
            polykey_dot_v2_dot_stream__operations__pb2.StreamCreateKeysRequest.SerializeToString,
            polykey_dot_v2_dot_stream__operations__pb2.StreamCreateKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamRotateKeys(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/polykey.v2.PolykeyService/StreamRotateKeys',
            polykey_dot_v2_dot_stream__operations__pb2.StreamRotateKeysRequest.SerializeToString,
            polykey_dot_v2_dot_stream__operations__pb2.StreamRotateKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamRevokeKeys(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/polykey.v2.PolykeyService/StreamRevokeKeys',
            polykey_dot_v2_dot_stream__operations__pb2.StreamRevokeKeysRequest.SerializeToString,
            polykey_dot_v2_dot_stream__operations__pb2.StreamRevokeKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamUpdateKeyMetadata(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/polykey.v2.PolykeyService/StreamUpdateKeyMetadata',
            polykey_dot_v2_dot_stream__operations__pb2.StreamUpdateKeyMetadataRequest.SerializeToString,
            polykey_dot_v2_dot_stream__operations__pb2.StreamUpdateKeyMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamGetKeyMetadata(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/polykey.v2.PolykeyService/StreamGetKeyMetadata',
            polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeyMetadataRequest.SerializeToString,
            polykey_dot_v2_dot_stream__operations__pb2.StreamGetKeyMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Authenticate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/Authenticate',
            polykey_dot_v2_dot_auth__pb2.AuthenticateRequest.SerializeToString,
            polykey_dot_v2_dot_auth__pb2.AuthenticateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RefreshToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/RefreshToken',
            polykey_dot_v2_dot_auth__pb2.RefreshTokenRequest.SerializeToString,
            polykey_dot_v2_dot_auth__pb2.RefreshTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RevokeToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/RevokeToken',
            polykey_dot_v2_dot_auth__pb2.RevokeTokenRequest.SerializeToString,
            polykey_dot_v2_dot_auth__pb2.RevokeTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/batch_operations.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/batch_operations.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from spounge.polykey.v2 import common_pb2 as polykey_dot_v2_dot_common__pb2
from spounge.polykey.v2 import key_types_pb2 as polykey_dot_v2_dot_key__types__pb2
from spounge.polykey.v2 import single_operations_pb2 as polykey_dot_v2_dot_single__operations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!polykey/v2/batch_operations.proto\x12\npolykey.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17polykey/v2/common.proto\x1a\x1apolykey/v2/key_types.proto\x1a\"polykey/v2/single_operations.proto\"f\n\x0eKeyRequestItem\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x18\n\x07version\x18\x02 \x01(\x05R\x07version\x12#\n\rskip_metadata\x18\x03 \x01(\x08R\x0cskipMetadata\"\xfa\x01\n\x13\x42\x61tchGetKeysRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12.\n\x04keys\x18\x03 \x03(\x0b\x32\x1a.polykey.v2.KeyRequestItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x04 \x01(\x08R\x0f\x63ontinueOnError\"\x85\x01\n\x12\x42\x61tchGetKeysResult\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x36\n\x07success\x18\x02 \x01(\x0b\x32\x1a.polykey.v2.GetKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xe9\x01\n\x14\x42\x61tchGetKeysResponse\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\x1e.polykey.v2.BatchGetKeysResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCount\"\xbd\x05\n\rCreateKeyItem\x12.\n\x08key_type\x18\x01 \x01(\x0e\x32\x13.polykey.v2.KeyTypeR\x07keyType\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x37\n\x04tags\x18\x03 \x03(\x0b\x32#.polykey.v2.CreateKeyItem.TagsEntryR\x04tags\x12\x39\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12>\n\x1binitial_authorized_contexts\x18\x05 \x03(\tR\x19initialAuthorizedContexts\x12V\n\x0f\x61\x63\x63\x65ss_policies\x18\x06 \x03(\x0b\x32-.polykey.v2.CreateKeyItem.AccessPoliciesEntryR\x0e\x61\x63\x63\x65ssPolicies\x12/\n\x13\x64\x61ta_classification\x18\x07 \x01(\tR\x12\x64\x61taClassification\x12\\\n\x11generation_params\x18\x08 \x03(\x0b\x32/.polykey.v2.CreateKeyItem.GenerationParamsEntryR\x10generationParams\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x41\n\x13\x41\x63\x63\x65ssPoliciesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15GenerationParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xd6\x01\n\x16\x42\x61tchCreateKeysRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12-\n\x04keys\x18\x02 \x03(\x0b\x32\x19.polykey.v2.CreateKeyItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x03 \x01(\x08R\x0f\x63ontinueOnError\x12\x16\n\x06\x61tomic\x18\x04 \x01(\x08R\x06\x61tomic\"\x99\x01\n\x15\x42\x61tchCreateKeysResult\x12#\n\rrequest_index\x18\x01 \x01(\x05R\x0crequestIndex\x12\x39\n\x07success\x18\x02 \x01(\x0b\x32\x1d.polykey.v2.CreateKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xef\x01\n\x17\x42\x61tchCreateKeysResponse\x12;\n\x07results\x18\x01 \x03(\x0b\x32!.polykey.v2.BatchCreateKeysResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCount\"\xef\x02\n\rRotateKeyItem\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x38\n\x08strategy\x18\x02 \x01(\x0e\x32\x1c.polykey.v2.RotationStrategyR\x08strategy\x12\x30\n\x14grace_period_seconds\x18\x03 \x01(\x05R\x12gracePeriodSeconds\x12\\\n\x11generation_params\x18\x04 \x03(\x0b\x32/.polykey.v2.RotateKeyItem.GenerationParamsEntryR\x10generationParams\x12\x38\n\x18preserve_access_policies\x18\x05 \x01(\x08R\x16preserveAccessPolicies\x1a\x43\n\x15GenerationParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xd6\x01\n\x16\x42\x61tchRotateKeysRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12-\n\x04keys\x18\x02 \x03(\x0b\x32\x19.polykey.v2.RotateKeyItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x03 \x01(\x08R\x0f\x63ontinueOnError\x12\x16\n\x06\x61tomic\x18\x04 \x01(\x08R\x06\x61tomic\"\x8b\x01\n\x15\x42\x61tchRotateKeysResult\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x39\n\x07success\x18\x02 \x01(\x0b\x32\x1d.polykey.v2.RotateKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xef\x01\n\x17\x42\x61tchRotateKeysResponse\x12;\n\x07results\x18\x01 \x03(\x0b\x32!.polykey.v2.BatchRotateKeysResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCount\"\xe8\x01\n\rRevokeKeyItem\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12+\n\x11revocation_reason\x18\x02 \x01(\tR\x10revocationReason\x12\x1c\n\timmediate\x18\x03 \x01(\x08R\timmediate\x12=\n\x0c\x65\x66\x66\x65\x63tive_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65\x66\x66\x65\x63tiveAt\x12\x36\n\x17notify_external_systems\x18\x05 \x01(\x08R\x15notifyExternalSystems\"\xd6\x01\n\x16\x42\x61tchRevokeKeysRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12-\n\x04keys\x18\x02 \x03(\x0b\x32\x19.polykey.v2.RevokeKeyItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x03 \x01(\x08R\x0f\x63ontinueOnError\x12\x16\n\x06\x61tomic\x18\x04 \x01(\x08R\x06\x61tomic\"l\n\x15\x42\x61tchRevokeKeysResult\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1a\n\x07success\x18\x02 \x01(\x08H\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xef\x01\n\x17\x42\x61tchRevokeKeysResponse\x12;\n\x07results\x18\x01 \x03(\x0b\x32!.polykey.v2.BatchRevokeKeysResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCount\"\xba\x05\n\x15UpdateKeyMetadataItem\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12P\n\x0btags_to_add\x18\x03 \x03(\x0b\x32\x30.polykey.v2.UpdateKeyMetadataItem.TagsToAddEntryR\ttagsToAdd\x12$\n\x0etags_to_remove\x18\x04 \x03(\tR\x0ctagsToRemove\x12&\n\x0f\x63ontexts_to_add\x18\x05 \x03(\tR\rcontextsToAdd\x12,\n\x12\x63ontexts_to_remove\x18\x06 \x03(\tR\x10\x63ontextsToRemove\x12\x65\n\x12policies_to_update\x18\x07 \x03(\x0b\x32\x37.polykey.v2.UpdateKeyMetadataItem.PoliciesToUpdateEntryR\x10policiesToUpdate\x12>\n\nexpires_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\texpiresAt\x88\x01\x01\x12\x34\n\x13\x64\x61ta_classification\x18\t \x01(\tH\x02R\x12\x64\x61taClassification\x88\x01\x01\x1a<\n\x0eTagsToAddEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15PoliciesToUpdateEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\r\n\x0b_expires_atB\x16\n\x14_data_classification\"\xe5\x01\n\x1d\x42\x61tchUpdateKeyMetadataRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12\x35\n\x04keys\x18\x02 \x03(\x0b\x32!.polykey.v2.UpdateKeyMetadataItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x03 \x01(\x08R\x0f\x63ontinueOnError\x12\x16\n\x06\x61tomic\x18\x04 \x01(\x08R\x06\x61tomic\"s\n\x1c\x42\x61tchUpdateKeyMetadataResult\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1a\n\x07success\x18\x02 \x01(\x08H\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xfd\x01\n\x1e\x42\x61tchUpdateKeyMetadataResponse\x12\x42\n\x07results\x18\x01 \x03(\x0b\x32(.polykey.v2.BatchUpdateKeyMetadataResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCount\"\xb1\x01\n\x12GetKeyMetadataItem\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x34\n\x16include_access_history\x18\x02 \x01(\x08R\x14includeAccessHistory\x12\x34\n\x16include_policy_details\x18\x03 \x01(\x08R\x14includePolicyDetails\x12\x18\n\x07version\x18\x04 \x01(\x05R\x07version\"\x85\x02\n\x1a\x42\x61tchGetKeyMetadataRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12\x32\n\x04keys\x18\x03 \x03(\x0b\x32\x1e.polykey.v2.GetKeyMetadataItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x04 \x01(\x08R\x0f\x63ontinueOnError\"\x94\x01\n\x19\x42\x61tchGetKeyMetadataResult\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12>\n\x07success\x18\x02 \x01(\x0b\x32\".polykey.v2.GetKeyMetadataResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xf7\x01\n\x1b\x42\x61tchGetKeyMetadataResponse\x12?\n\x07results\x18\x01 \x03(\x0b\x32%.polykey.v2.BatchGetKeyMetadataResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCountB\xb0\x01\n\x0e\x63om.polykey.v2B\x14\x42\x61tchOperationsProtoP\x01Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.batch_operations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\024BatchOperationsProtoP\001Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_CREATEKEYITEM_TAGSENTRY']._loaded_options = None
  _globals['_CREATEKEYITEM_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEKEYITEM_ACCESSPOLICIESENTRY']._loaded_options = None
  _globals['_CREATEKEYITEM_ACCESSPOLICIESENTRY']._serialized_options = b'8\001'
  _globals['_CREATEKEYITEM_GENERATIONPARAMSENTRY']._loaded_options = None
  _globals['_CREATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_ROTATEKEYITEM_GENERATIONPARAMSENTRY']._loaded_options = None
  _globals['_ROTATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEKEYMETADATAITEM_TAGSTOADDENTRY']._loaded_options = None
  _globals['_UPDATEKEYMETADATAITEM_TAGSTOADDENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEKEYMETADATAITEM_POLICIESTOUPDATEENTRY']._loaded_options = None
  _globals['_UPDATEKEYMETADATAITEM_POLICIESTOUPDATEENTRY']._serialized_options = b'8\001'
  _globals['_KEYREQUESTITEM']._serialized_start=171
  _globals['_KEYREQUESTITEM']._serialized_end=273
  _globals['_BATCHGETKEYSREQUEST']._serialized_start=276
  _globals['_BATCHGETKEYSREQUEST']._serialized_end=526
  _globals['_BATCHGETKEYSRESULT']._serialized_start=529
  _globals['_BATCHGETKEYSRESULT']._serialized_end=662
  _globals['_BATCHGETKEYSRESPONSE']._serialized_start=665
  _globals['_BATCHGETKEYSRESPONSE']._serialized_end=898
  _globals['_CREATEKEYITEM']._serialized_start=901
  _globals['_CREATEKEYITEM']._serialized_end=1602
  _globals['_CREATEKEYITEM_TAGSENTRY']._serialized_start=1411
  _globals['_CREATEKEYITEM_TAGSENTRY']._serialized_end=1466
  _globals['_CREATEKEYITEM_ACCESSPOLICIESENTRY']._serialized_start=1468
  _globals['_CREATEKEYITEM_ACCESSPOLICIESENTRY']._serialized_end=1533
  _globals['_CREATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_start=1535
  _globals['_CREATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_end=1602
  _globals['_BATCHCREATEKEYSREQUEST']._serialized_start=1605
  _globals['_BATCHCREATEKEYSREQUEST']._serialized_end=1819
  _globals['_BATCHCREATEKEYSRESULT']._serialized_start=1822
  _globals['_BATCHCREATEKEYSRESULT']._serialized_end=1975
  _globals['_BATCHCREATEKEYSRESPONSE']._serialized_start=1978
  _globals['_BATCHCREATEKEYSRESPONSE']._serialized_end=2217
  _globals['_ROTATEKEYITEM']._serialized_start=2220
  _globals['_ROTATEKEYITEM']._serialized_end=2587
  _globals['_ROTATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_start=1535
  _globals['_ROTATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_end=1602
  _globals['_BATCHROTATEKEYSREQUEST']._serialized_start=2590
  _globals['_BATCHROTATEKEYSREQUEST']._serialized_end=2804
  _globals['_BATCHROTATEKEYSRESULT']._serialized_start=2807
  _globals['_BATCHROTATEKEYSRESULT']._serialized_end=2946
  _globals['_BATCHROTATEKEYSRESPONSE']._serialized_start=2949
  _globals['_BATCHROTATEKEYSRESPONSE']._serialized_end=3188
  _globals['_REVOKEKEYITEM']._serialized_start=3191
  _globals['_REVOKEKEYITEM']._serialized_end=3423
  _globals['_BATCHREVOKEKEYSREQUEST']._serialized_start=3426
  _globals['_BATCHREVOKEKEYSREQUEST']._serialized_end=3640
  _globals['_BATCHREVOKEKEYSRESULT']._serialized_start=3642
  _globals['_BATCHREVOKEKEYSRESULT']._serialized_end=3750
  _globals['_BATCHREVOKEKEYSRESPONSE']._serialized_start=3753
  _globals['_BATCHREVOKEKEYSRESPONSE']._serialized_end=3992
  _globals['_UPDATEKEYMETADATAITEM']._serialized_start=3995
  _globals['_UPDATEKEYMETADATAITEM']._serialized_end=4693
  _globals['_UPDATEKEYMETADATAITEM_TAGSTOADDENTRY']._serialized_start=4509
  _globals['_UPDATEKEYMETADATAITEM_TAGSTOADDENTRY']._serialized_end=4569
  _globals['_UPDATEKEYMETADATAITEM_POLICIESTOUPDATEENTRY']._serialized_start=4571
  _globals['_UPDATEKEYMETADATAITEM_POLICIESTOUPDATEENTRY']._serialized_end=4638
  _globals['_BATCHUPDATEKEYMETADATAREQUEST']._serialized_start=4696
  _globals['_BATCHUPDATEKEYMETADATAREQUEST']._serialized_end=4925
  _globals['_BATCHUPDATEKEYMETADATARESULT']._serialized_start=4927
  _globals['_BATCHUPDATEKEYMETADATARESULT']._serialized_end=5042
  _globals['_BATCHUPDATEKEYMETADATARESPONSE']._serialized_start=5045
  _globals['_BATCHUPDATEKEYMETADATARESPONSE']._serialized_end=5298
  _globals['_GETKEYMETADATAITEM']._serialized_start=5301
  _globals['_GETKEYMETADATAITEM']._serialized_end=5478
  _globals['_BATCHGETKEYMETADATAREQUEST']._serialized_start=5481
  _globals['_BATCHGETKEYMETADATAREQUEST']._serialized_end=5742
  _globals['_BATCHGETKEYMETADATARESULT']._serialized_start=5745
  _globals['_BATCHGETKEYMETADATARESULT']._serialized_end=5893
  _globals['_BATCHGETKEYMETADATARESPONSE']._serialized_start=5896
  _globals['_BATCHGETKEYMETADATARESPONSE']._serialized_end=6143
# @@protoc_insertion_point(module_scope)



# Auto-generated __init__.py
from . import calendar_period_pb2, calendar_period_pb2_grpc, color_pb2, color_pb2_grpc, date_pb2, date_pb2_grpc, datetime_pb2, datetime_pb2_grpc, dayofweek_pb2, dayofweek_pb2_grpc, decimal_pb2, decimal_pb2_grpc, expr_pb2, expr_pb2_grpc, fraction_pb2, fraction_pb2_grpc, interval_pb2, interval_pb2_grpc, latlng_pb2, latlng_pb2_grpc, localized_text_pb2, localized_text_pb2_grpc, money_pb2, money_pb2_grpc, month_pb2, month_pb2_grpc, phone_number_pb2, phone_number_pb2_grpc, postal_address_pb2, postal_address_pb2_grpc, quaternion_pb2, quaternion_pb2_grpc, timeofday_pb2, timeofday_pb2_grpc

__all__ = ["calendar_period_pb2", "calendar_period_pb2_grpc", "color_pb2", "color_pb2_grpc", "date_pb2", "date_pb2_grpc", "datetime_pb2", "datetime_pb2_grpc", "dayofweek_pb2", "dayofweek_pb2_grpc", "decimal_pb2", "decimal_pb2_grpc", "expr_pb2", "expr_pb2_grpc", "fraction_pb2", "fraction_pb2_grpc", "interval_pb2", "interval_pb2_grpc", "latlng_pb2", "latlng_pb2_grpc", "localized_text_pb2", "localized_text_pb2_grpc", "money_pb2", "money_pb2_grpc", "month_pb2", "month_pb2_grpc", "phone_number_pb2", "phone_number_pb2_grpc", "postal_address_pb2", "postal_address_pb2_grpc", "quaternion_pb2", "quaternion_pb2_grpc", "timeofday_pb2", "timeofday_pb2_grpc"]



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from workflow.v2 import (
    execution_service_pb2 as workflow_dot_v2_dot_execution__service__pb2,
)


class ExecutionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StartExecution = channel.unary_unary(
            "/workflow.v2.ExecutionService/StartExecution",
            request_serializer=workflow_dot_v2_dot_execution__service__pb2.StartExecutionRequest.SerializeToString,
            response_deserializer=workflow_dot_v2_dot_execution__service__pb2.StartExecutionResponse.FromString,
            _registered_method=True,
        )
        self.GetExecution = channel.unary_unary(
            "/workflow.v2.ExecutionService/GetExecution",
            request_serializer=workflow_dot_v2_dot_execution__service__pb2.GetExecutionRequest.SerializeToString,
            response_deserializer=workflow_dot_v2_dot_execution__service__pb2.GetExecutionResponse.FromString,
            _registered_method=True,
        )
        self.ListExecutions = channel.unary_unary(
            "/workflow.v2.ExecutionService/ListExecutions",
            request_serializer=workflow_dot_v2_dot_execution__service__pb2.ListExecutionsRequest.SerializeToString,
            response_deserializer=workflow_dot_v2_dot_execution__service__pb2.ListExecutionsResponse.FromString,
            _registered_method=True,
        )
        self.CancelExecution = channel.unary_unary(
            "/workflow.v2.ExecutionService/CancelExecution",
            request_serializer=workflow_dot_v2_dot_execution__service__pb2.CancelExecutionRequest.SerializeToString,
            response_deserializer=workflow_dot_v2_dot_execution__service__pb2.CancelExecutionResponse.FromString,
            _registered_method=True,
        )
        self.StreamExecution = channel.unary_stream(
            "/workflow.v2.ExecutionService/StreamExecution",
            request_serializer=workflow_dot_v2_dot_execution__service__pb2.StreamExecutionRequest.SerializeToString,
            response_deserializer=workflow_dot_v2_dot_execution__service__pb2.StreamExecutionResponse.FromString,
            _registered_method=True,
        )


class ExecutionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StartExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListExecutions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CancelExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StreamExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ExecutionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "StartExecution": grpc.unary_unary_rpc_method_handler(
            servicer.StartExecution,
            request_deserializer=workflow_dot_v2_dot_execution__service__pb2.StartExecutionRequest.FromString,
            response_serializer=workflow_dot_v2_dot_execution__service__pb2.StartExecutionResponse.SerializeToString,
        ),
        "GetExecution": grpc.unary_unary_rpc_method_handler(
            servicer.GetExecution,
            request_deserializer=workflow_dot_v2_dot_execution__service__pb2.GetExecutionRequest.FromString,
            response_serializer=workflow_dot_v2_dot_execution__service__pb2.GetExecutionResponse.SerializeToString,
        ),
        "ListExecutions": grpc.unary_unary_rpc_method_handler(
            servicer.ListExecutions,
            request_deserializer=workflow_dot_v2_dot_execution__service__pb2.ListExecutionsRequest.FromString,
            response_serializer=workflow_dot_v2_dot_execution__service__pb2.ListExecutionsResponse.SerializeToString,
        ),
        "CancelExecution": grpc.unary_unary_rpc_method_handler(
            servicer.CancelExecution,
            request_deserializer=workflow_dot_v2_dot_execution__service__pb2.CancelExecutionRequest.FromString,
            response_serializer=workflow_dot_v2_dot_execution__service__pb2.CancelExecutionResponse.SerializeToString,
        ),
        "StreamExecution": grpc.unary_stream_rpc_method_handler(
            servicer.StreamExecution,
            request_deserializer=workflow_dot_v2_dot_execution__service__pb2.StreamExecutionRequest.FromString,
            response_serializer=workflow_dot_v2_dot_execution__service__pb2.StreamExecutionResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "workflow.v2.ExecutionService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "workflow.v2.ExecutionService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class ExecutionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StartExecution(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/workflow.v2.ExecutionService/StartExecution",
            workflow_dot_v2_dot_execution__service__pb2.StartExecutionRequest.SerializeToString,
            workflow_dot_v2_dot_execution__service__pb2.StartExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetExecution(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/workflow.v2.ExecutionService/GetExecution",
            workflow_dot_v2_dot_execution__service__pb2.GetExecutionRequest.SerializeToString,
            workflow_dot_v2_dot_execution__service__pb2.GetExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ListExecutions(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/workflow.v2.ExecutionService/ListExecutions",
            workflow_dot_v2_dot_execution__service__pb2.ListExecutionsRequest.SerializeToString,
            workflow_dot_v2_dot_execution__service__pb2.ListExecutionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def CancelExecution(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/workflow.v2.ExecutionService/CancelExecution",
            workflow_dot_v2_dot_execution__service__pb2.CancelExecutionRequest.SerializeToString,
            workflow_dot_v2_dot_execution__service__pb2.CancelExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def StreamExecution(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/workflow.v2.ExecutionService/StreamExecution",
            workflow_dot_v2_dot_execution__service__pb2.StreamExecutionRequest.SerializeToString,
            workflow_dot_v2_dot_execution__service__pb2.StreamExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/longrunning/operations.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "google/longrunning/operations.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#google/longrunning/operations.proto\x12\x12google.longrunning\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x19google/protobuf/any.proto\x1a google/protobuf/descriptor.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x17google/rpc/status.proto"\xcf\x01\n\tOperation\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x30\n\x08metadata\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x08metadata\x12\x12\n\x04\x64one\x18\x03 \x01(\x08R\x04\x64one\x12*\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x12.google.rpc.StatusH\x00R\x05\x65rror\x12\x32\n\x08response\x18\x05 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08responseB\x08\n\x06result")\n\x13GetOperationRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name"\x7f\n\x15ListOperationsRequest\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12\x16\n\x06\x66ilter\x18\x01 \x01(\tR\x06\x66ilter\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken"\x7f\n\x16ListOperationsResponse\x12=\n\noperations\x18\x01 \x03(\x0b\x32\x1d.google.longrunning.OperationR\noperations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken",\n\x16\x43\x61ncelOperationRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name",\n\x16\x44\x65leteOperationRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name"_\n\x14WaitOperationRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x33\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout"Y\n\rOperationInfo\x12#\n\rresponse_type\x18\x01 \x01(\tR\x0cresponseType\x12#\n\rmetadata_type\x18\x02 \x01(\tR\x0cmetadataType2\xaa\x05\n\nOperations\x12\x94\x01\n\x0eListOperations\x12).google.longrunning.ListOperationsRequest\x1a*.google.longrunning.ListOperationsResponse"+\xda\x41\x0bname,filter\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/{name=operations}\x12\x7f\n\x0cGetOperation\x12\'.google.longrunning.GetOperationRequest\x1a\x1d.google.longrunning.Operation"\'\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/{name=operations/**}\x12~\n\x0f\x44\x65leteOperation\x12*.google.longrunning.DeleteOperationRequest\x1a\x16.google.protobuf.Empty"\'\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1a*\x18/v1/{name=operations/**}\x12\x88\x01\n\x0f\x43\x61ncelOperation\x12*.google.longrunning.CancelOperationRequest\x1a\x16.google.protobuf.Empty"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$"\x1f/v1/{name=operations/**}:cancel:\x01*\x12Z\n\rWaitOperation\x12(.google.longrunning.WaitOperationRequest\x1a\x1d.google.longrunning.Operation"\x00\x1a\x1d\xca\x41\x1alongrunning.googleapis.com:i\n\x0eoperation_info\x12\x1e.google.protobuf.MethodOptions\x18\x99\x08 \x01(\x0b\x32!.google.longrunning.OperationInfoR\roperationInfoB\xda\x01\n\x16\x63om.google.longrunningB\x0fOperationsProtoP\x01ZCcloud.google.com/go/longrunning/autogen/longrunningpb;longrunningpb\xf8\x01\x01\xa2\x02\x03GLX\xaa\x02\x12Google.Longrunning\xca\x02\x12Google\\Longrunning\xe2\x02\x1eGoogle\\Longrunning\\GPBMetadata\xea\x02\x13Google::Longrunningb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "google.longrunning.operations_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\026com.google.longrunningB\017OperationsProtoP\001ZCcloud.google.com/go/longrunning/autogen/longrunningpb;longrunningpb\370\001\001\242\002\003GLX\252\002\022Google.Longrunning\312\002\022Google\\Longrunning\342\002\036Google\\Longrunning\\GPBMetadata\352\002\023Google::Longrunning"
    _globals["_OPERATIONS"]._loaded_options = None
    _globals["_OPERATIONS"]._serialized_options = b"\312A\032longrunning.googleapis.com"
    _globals["_OPERATIONS"].methods_by_name["ListOperations"]._loaded_options = None
    _globals["_OPERATIONS"].methods_by_name[
        "ListOperations"
    ]._serialized_options = (
        b"\332A\013name,filter\202\323\344\223\002\027\022\025/v1/{name=operations}"
    )
    _globals["_OPERATIONS"].methods_by_name["GetOperation"]._loaded_options = None
    _globals["_OPERATIONS"].methods_by_name[
        "GetOperation"
    ]._serialized_options = (
        b"\332A\004name\202\323\344\223\002\032\022\030/v1/{name=operations/**}"
    )
    _globals["_OPERATIONS"].methods_by_name["DeleteOperation"]._loaded_options = None
    _globals["_OPERATIONS"].methods_by_name[
        "DeleteOperation"
    ]._serialized_options = (
        b"\332A\004name\202\323\344\223\002\032*\030/v1/{name=operations/**}"
    )
    _globals["_OPERATIONS"].methods_by_name["CancelOperation"]._loaded_options = None
    _globals["_OPERATIONS"].methods_by_name[
        "CancelOperation"
    ]._serialized_options = (
        b'\332A\004name\202\323\344\223\002$"\037/v1/{name=operations/**}:cancel:\001*'
    )
    _globals["_OPERATION"]._serialized_start = 262
    _globals["_OPERATION"]._serialized_end = 469
    _globals["_GETOPERATIONREQUEST"]._serialized_start = 471
    _globals["_GETOPERATIONREQUEST"]._serialized_end = 512
    _globals["_LISTOPERATIONSREQUEST"]._serialized_start = 514
    _globals["_LISTOPERATIONSREQUEST"]._serialized_end = 641
    _globals["_LISTOPERATIONSRESPONSE"]._serialized_start = 643
    _globals["_LISTOPERATIONSRESPONSE"]._serialized_end = 770
    _globals["_CANCELOPERATIONREQUEST"]._serialized_start = 772
    _globals["_CANCELOPERATIONREQUEST"]._serialized_end = 816
    _globals["_DELETEOPERATIONREQUEST"]._serialized_start = 818
    _globals["_DELETEOPERATIONREQUEST"]._serialized_end = 862
    _globals["_WAITOPERATIONREQUEST"]._serialized_start = 864
    _globals["_WAITOPERATIONREQUEST"]._serialized_end = 959
    _globals["_OPERATIONINFO"]._serialized_start = 961
    _globals["_OPERATIONINFO"]._serialized_end = 1050
    _globals["_OPERATIONS"]._serialized_start = 1053
    _globals["_OPERATIONS"]._serialized_end = 1735
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from api.v2 import (
    auth_gateway_service_pb2 as api_dot_v2_dot_auth__gateway__service__pb2,
)


class AuthGatewayServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Login = channel.unary_unary(
            "/api.v2.AuthGatewayService/Login",
            request_serializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLoginRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLoginResponse.FromString,
            _registered_method=True,
        )
        self.RefreshToken = channel.unary_unary(
            "/api.v2.AuthGatewayService/RefreshToken",
            request_serializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceRefreshTokenRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceRefreshTokenResponse.FromString,
            _registered_method=True,
        )
        self.Logout = channel.unary_unary(
            "/api.v2.AuthGatewayService/Logout",
            request_serializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLogoutRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLogoutResponse.FromString,
            _registered_method=True,
        )


class AuthGatewayServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Logout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AuthGatewayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Login": grpc.unary_unary_rpc_method_handler(
            servicer.Login,
            request_deserializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLoginRequest.FromString,
            response_serializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLoginResponse.SerializeToString,
        ),
        "RefreshToken": grpc.unary_unary_rpc_method_handler(
            servicer.RefreshToken,
            request_deserializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceRefreshTokenRequest.FromString,
            response_serializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceRefreshTokenResponse.SerializeToString,
        ),
        "Logout": grpc.unary_unary_rpc_method_handler(
            servicer.Logout,
            request_deserializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLogoutRequest.FromString,
            response_serializer=api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLogoutResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "api.v2.AuthGatewayService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "api.v2.AuthGatewayService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class AuthGatewayService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Login(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.AuthGatewayService/Login",
            api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLoginRequest.SerializeToString,
            api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLoginResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def RefreshToken(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.AuthGatewayService/RefreshToken",
            api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceRefreshTokenRequest.SerializeToString,
            api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceRefreshTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Logout(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.AuthGatewayService/Logout",
            api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLogoutRequest.SerializeToString,
            api_dot_v2_dot_auth__gateway__service__pb2.AuthGatewayServiceLogoutResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v2/user_gateway_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "api/v2/user_gateway_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!api/v2/user_gateway_service.proto\x12\x06\x61pi.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1auser/v2/user_service.proto"W\n\'UserGatewayServiceGetUserProfileRequest\x12,\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x05\x65mpty"\x86\x01\n(UserGatewayServiceGetUserProfileResponse\x12Z\n\x19get_user_profile_response\x18\x01 \x01(\x0b\x32\x1f.user.v2.GetUserProfileResponseR\x16getUserProfileResponse"\x8e\x01\n*UserGatewayServiceUpdateUserProfileRequest\x12`\n\x1bupdate_user_profile_request\x18\x01 \x01(\x0b\x32!.user.v2.UpdateUserProfileRequestR\x18updateUserProfileRequest"\x92\x01\n+UserGatewayServiceUpdateUserProfileResponse\x12\x63\n\x1cupdate_user_profile_response\x18\x01 \x01(\x0b\x32".user.v2.UpdateUserProfileResponseR\x19updateUserProfileResponse2\xc0\x02\n\x12UserGatewayService\x12\x8d\x01\n\x0eGetUserProfile\x12/.api.v2.UserGatewayServiceGetUserProfileRequest\x1a\x30.api.v2.UserGatewayServiceGetUserProfileResponse"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v2/user/profile\x12\x99\x01\n\x11UpdateUserProfile\x12\x32.api.v2.UserGatewayServiceUpdateUserProfileRequest\x1a\x33.api.v2.UserGatewayServiceUpdateUserProfileResponse"\x1b\x82\xd3\xe4\x93\x02\x15\x32\x10/v2/user/profile:\x01*B\x98\x01\n\ncom.api.v2B\x17UserGatewayServiceProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V2\xca\x02\x06\x41pi\\V2\xe2\x02\x12\x41pi\\V2\\GPBMetadata\xea\x02\x07\x41pi::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "api.v2.user_gateway_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\ncom.api.v2B\027UserGatewayServiceProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\242\002\003AXX\252\002\006Api.V2\312\002\006Api\\V2\342\002\022Api\\V2\\GPBMetadata\352\002\007Api::V2"
    _globals["_USERGATEWAYSERVICE"].methods_by_name[
        "GetUserProfile"
    ]._loaded_options = None
    _globals["_USERGATEWAYSERVICE"].methods_by_name[
        "GetUserProfile"
    ]._serialized_options = b"\202\323\344\223\002\022\022\020/v2/user/profile"
    _globals["_USERGATEWAYSERVICE"].methods_by_name[
        "UpdateUserProfile"
    ]._loaded_options = None
    _globals["_USERGATEWAYSERVICE"].methods_by_name[
        "UpdateUserProfile"
    ]._serialized_options = b"\202\323\344\223\002\0252\020/v2/user/profile:\001*"
    _globals["_USERGATEWAYSERVICEGETUSERPROFILEREQUEST"]._serialized_start = 132
    _globals["_USERGATEWAYSERVICEGETUSERPROFILEREQUEST"]._serialized_end = 219
    _globals["_USERGATEWAYSERVICEGETUSERPROFILERESPONSE"]._serialized_start = 222
    _globals["_USERGATEWAYSERVICEGETUSERPROFILERESPONSE"]._serialized_end = 356
    _globals["_USERGATEWAYSERVICEUPDATEUSERPROFILEREQUEST"]._serialized_start = 359
    _globals["_USERGATEWAYSERVICEUPDATEUSERPROFILEREQUEST"]._serialized_end = 501
    _globals["_USERGATEWAYSERVICEUPDATEUSERPROFILERESPONSE"]._serialized_start = 504
    _globals["_USERGATEWAYSERVICEUPDATEUSERPROFILERESPONSE"]._serialized_end = 650
    _globals["_USERGATEWAYSERVICE"]._serialized_start = 653
    _globals["_USERGATEWAYSERVICE"]._serialized_end = 973
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spounge.polykey.v2 import metrics_pb2 as polykey_dot_v2_dot_metrics__pb2
from spounge.polykey.v2 import auth_pb2 as polykey_dot_v2_dot_auth__pb2
from spounge.polykey.v2 import single_operations_pb2 as polykey_dot_v2_dot_single__operations__pb2
from spounge.polykey.v2 import batch_operations_pb2 as polykey_dot_v2_dot_batch__operations__pb2
from spounge.polykey.v2 import stream_operations_pb2 as polykey_dot_v2_dot_stream__operations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18polykey/v2/service.proto\x12\npolykey.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x18polykey/v2/metrics.proto\x1a\x15polykey/v2/auth.proto\x1a\"polykey/v2/single_operations.proto\x1a!polykey/v2/batch_operations.proto\x1a\"polykey/v2/stream_operations.proto2\x81\x10\n\x0ePolykeyService\x12\x46\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x1f.polykey.v2.HealthCheckResponse\x12?\n\x06GetKey\x12\x19.polykey.v2.GetKeyRequest\x1a\x1a.polykey.v2.GetKeyResponse\x12\x45\n\x08ListKeys\x12\x1b.polykey.v2.ListKeysRequest\x1a\x1c.polykey.v2.ListKeysResponse\x12H\n\tCreateKey\x12\x1c.polykey.v2.CreateKeyRequest\x1a\x1d.polykey.v2.CreateKeyResponse\x12H\n\tRotateKey\x12\x1c.polykey.v2.RotateKeyRequest\x1a\x1d.polykey.v2.RotateKeyResponse\x12\x41\n\tRevokeKey\x12\x1c.polykey.v2.RevokeKeyRequest\x1a\x16.google.protobuf.Empty\x12Q\n\x11UpdateKeyMetadata\x12$.polykey.v2.UpdateKeyMetadataRequest\x1a\x16.google.protobuf.Empty\x12W\n\x0eGetKeyMetadata\x12!.polykey.v2.GetKeyMetadataRequest\x1a\".polykey.v2.GetKeyMetadataResponse\x12Q\n\x0c\x42\x61tchGetKeys\x12\x1f.polykey.v2.BatchGetKeysRequest\x1a .polykey.v2.BatchGetKeysResponse\x12Z\n\x0f\x42\x61tchCreateKeys\x12\".polykey.v2.BatchCreateKeysRequest\x1a#.polykey.v2.BatchCreateKeysResponse\x12Z\n\x0f\x42\x61tchRotateKeys\x12\".polykey.v2.BatchRotateKeysRequest\x1a#.polykey.v2.BatchRotateKeysResponse\x12Z\n\x0f\x42\x61tchRevokeKeys\x12\".polykey.v2.BatchRevokeKeysRequest\x1a#.polykey.v2.BatchRevokeKeysResponse\x12o\n\x16\x42\x61tchUpdateKeyMetadata\x12).polykey.v2.BatchUpdateKeyMetadataRequest\x1a*.polykey.v2.BatchUpdateKeyMetadataResponse\x12\x66\n\x13\x42\x61tchGetKeyMetadata\x12&.polykey.v2.BatchGetKeyMetadataRequest\x1a\'.polykey.v2.BatchGetKeyMetadataResponse\x12V\n\rStreamGetKeys\x12 .polykey.v2.StreamGetKeysRequest\x1a!.polykey.v2.StreamGetKeysResponse0\x01\x12\x61\n\x10StreamCreateKeys\x12#.polykey.v2.StreamCreateKeysRequest\x1a$.polykey.v2.StreamCreateKeysResponse(\x01\x30\x01\x12\x61\n\x10StreamRotateKeys\x12#.polykey.v2.StreamRotateKeysRequest\x1a$.polykey.v2.StreamRotateKeysResponse(\x01\x30\x01\x12\x61\n\x10StreamRevokeKeys\x12#.polykey.v2.StreamRevokeKeysRequest\x1a$.polykey.v2.StreamRevokeKeysResponse(\x01\x30\x01\x12v\n\x17StreamUpdateKeyMetadata\x12*.polykey.v2.StreamUpdateKeyMetadataRequest\x1a+.polykey.v2.StreamUpdateKeyMetadataResponse(\x01\x30\x01\x12m\n\x14StreamGetKeyMetadata\x12\'.polykey.v2.StreamGetKeyMetadataRequest\x1a(.polykey.v2.StreamGetKeyMetadataResponse(\x01\x30\x01\x12Q\n\x0c\x41uthenticate\x12\x1f.polykey.v2.AuthenticateRequest\x1a .polykey.v2.AuthenticateResponse\x12Q\n\x0cRefreshToken\x12\x1f.polykey.v2.RefreshTokenRequest\x1a .polykey.v2.RefreshTokenResponse\x12N\n\x0bRevokeToken\x12\x1e.polykey.v2.RevokeTokenRequest\x1a\x1f.polykey.v2.RevokeTokenResponseB\xa8\x01\n\x0e\x63om.polykey.v2B\x0cServiceProtoP\x01Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\014ServiceProtoP\001Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_POLYKEYSERVICE']._serialized_start=226
  _globals['_POLYKEYSERVICE']._serialized_end=2275
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from user.v2 import user_service_pb2 as user_dot_v2_dot_user__service__pb2


class UserServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUserProfile = channel.unary_unary(
            "/user.v2.UserService/GetUserProfile",
            request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.GetUserProfileResponse.FromString,
            _registered_method=True,
        )
        self.UpdateUserProfile = channel.unary_unary(
            "/user.v2.UserService/UpdateUserProfile",
            request_serializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileRequest.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileResponse.FromString,
            _registered_method=True,
        )
        self.AddManagedSecret = channel.unary_unary(
            "/user.v2.UserService/AddManagedSecret",
            request_serializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretRequest.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretResponse.FromString,
            _registered_method=True,
        )
        self.ListManagedSecrets = channel.unary_unary(
            "/user.v2.UserService/ListManagedSecrets",
            request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.ListManagedSecretsResponse.FromString,
            _registered_method=True,
        )
        self.GetManagedSecret = channel.unary_unary(
            "/user.v2.UserService/GetManagedSecret",
            request_serializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretRequest.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretResponse.FromString,
            _registered_method=True,
        )
        self.DeleteManagedSecret = channel.unary_unary(
            "/user.v2.UserService/DeleteManagedSecret",
            request_serializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretRequest.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretResponse.FromString,
            _registered_method=True,
        )


class UserServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AddManagedSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListManagedSecrets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetManagedSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteManagedSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetUserProfile": grpc.unary_unary_rpc_method_handler(
            servicer.GetUserProfile,
            request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.GetUserProfileResponse.SerializeToString,
        ),
        "UpdateUserProfile": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateUserProfile,
            request_deserializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileRequest.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileResponse.SerializeToString,
        ),
        "AddManagedSecret": grpc.unary_unary_rpc_method_handler(
            servicer.AddManagedSecret,
            request_deserializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretRequest.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretResponse.SerializeToString,
        ),
        "ListManagedSecrets": grpc.unary_unary_rpc_method_handler(
            servicer.ListManagedSecrets,
            request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.ListManagedSecretsResponse.SerializeToString,
        ),
        "GetManagedSecret": grpc.unary_unary_rpc_method_handler(
            servicer.GetManagedSecret,
            request_deserializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretRequest.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretResponse.SerializeToString,
        ),
        "DeleteManagedSecret": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteManagedSecret,
            request_deserializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretRequest.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "user.v2.UserService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("user.v2.UserService", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class UserService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUserProfile(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/GetUserProfile",
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            user_dot_v2_dot_user__service__pb2.GetUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def UpdateUserProfile(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/UpdateUserProfile",
            user_dot_v2_dot_user__service__pb2.UpdateUserProfileRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.UpdateUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def AddManagedSecret(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/AddManagedSecret",
            user_dot_v2_dot_user__service__pb2.AddManagedSecretRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.AddManagedSecretResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ListManagedSecrets(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/ListManagedSecrets",
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            user_dot_v2_dot_user__service__pb2.ListManagedSecretsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetManagedSecret(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/GetManagedSecret",
            user_dot_v2_dot_user__service__pb2.GetManagedSecretRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.GetManagedSecretResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def DeleteManagedSecret(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/DeleteManagedSecret",
            user_dot_v2_dot_user__service__pb2.DeleteManagedSecretRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.DeleteManagedSecretResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from llm.v2 import llm_pb2 as llm_dot_v2_dot_llm__pb2


class LLMProviderServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GenerateText = channel.unary_unary(
            "/llm.v2.LLMProviderService/GenerateText",
            request_serializer=llm_dot_v2_dot_llm__pb2.GenerateTextRequest.SerializeToString,
            response_deserializer=llm_dot_v2_dot_llm__pb2.GenerateTextResponse.FromString,
            _registered_method=True,
        )
        self.GenerateTextStream = channel.unary_stream(
            "/llm.v2.LLMProviderService/GenerateTextStream",
            request_serializer=llm_dot_v2_dot_llm__pb2.GenerateTextStreamRequest.SerializeToString,
            response_deserializer=llm_dot_v2_dot_llm__pb2.GenerateTextStreamResponse.FromString,
            _registered_method=True,
        )
        self.GenerateEmbedding = channel.unary_unary(
            "/llm.v2.LLMProviderService/GenerateEmbedding",
            request_serializer=llm_dot_v2_dot_llm__pb2.GenerateEmbeddingRequest.SerializeToString,
            response_deserializer=llm_dot_v2_dot_llm__pb2.GenerateEmbeddingResponse.FromString,
            _registered_method=True,
        )


class LLMProviderServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GenerateText(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GenerateTextStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GenerateEmbedding(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_LLMProviderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GenerateText": grpc.unary_unary_rpc_method_handler(
            servicer.GenerateText,
            request_deserializer=llm_dot_v2_dot_llm__pb2.GenerateTextRequest.FromString,
            response_serializer=llm_dot_v2_dot_llm__pb2.GenerateTextResponse.SerializeToString,
        ),
        "GenerateTextStream": grpc.unary_stream_rpc_method_handler(
            servicer.GenerateTextStream,
            request_deserializer=llm_dot_v2_dot_llm__pb2.GenerateTextStreamRequest.FromString,
            response_serializer=llm_dot_v2_dot_llm__pb2.GenerateTextStreamResponse.SerializeToString,
        ),
        "GenerateEmbedding": grpc.unary_unary_rpc_method_handler(
            servicer.GenerateEmbedding,
            request_deserializer=llm_dot_v2_dot_llm__pb2.GenerateEmbeddingRequest.FromString,
            response_serializer=llm_dot_v2_dot_llm__pb2.GenerateEmbeddingResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "llm.v2.LLMProviderService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "llm.v2.LLMProviderService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class LLMProviderService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GenerateText(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/llm.v2.LLMProviderService/GenerateText",
            llm_dot_v2_dot_llm__pb2.GenerateTextRequest.SerializeToString,
            llm_dot_v2_dot_llm__pb2.GenerateTextResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GenerateTextStream(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/llm.v2.LLMProviderService/GenerateTextStream",
            llm_dot_v2_dot_llm__pb2.GenerateTextStreamRequest.SerializeToString,
            llm_dot_v2_dot_llm__pb2.GenerateTextStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GenerateEmbedding(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/llm.v2.LLMProviderService/GenerateEmbedding",
            llm_dot_v2_dot_llm__pb2.GenerateEmbeddingRequest.SerializeToString,
            llm_dot_v2_dot_llm__pb2.GenerateEmbeddingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: workflow/v2/workflow_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "workflow/v2/workflow_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"workflow/v2/workflow_service.proto\x12\x0bworkflow.v2\x1a\x16\x63ommon/v2/common.proto\x1a google/protobuf/field_mask.proto\x1a\x1aworkflow/v2/workflow.proto"\x93\x01\n\x15\x43reateWorkflowRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12/\n\x05steps\x18\x03 \x03(\x0b\x32\x19.workflow.v2.WorkflowStepR\x05stepsB\x0e\n\x0c_description"Q\n\x16\x43reateWorkflowResponse\x12\x37\n\x08workflow\x18\x01 \x01(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08workflow"`\n\x12GetWorkflowRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12\x1d\n\x07version\x18\x02 \x01(\x05H\x00R\x07version\x88\x01\x01\x42\n\n\x08_version"N\n\x13GetWorkflowResponse\x12\x37\n\x08workflow\x18\x01 \x01(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08workflow"\xf1\x01\n\x15UpdateWorkflowRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12;\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12/\n\x05steps\x18\x05 \x03(\x0b\x32\x19.workflow.v2.WorkflowStepR\x05stepsB\x0e\n\x0c_description"Q\n\x16UpdateWorkflowResponse\x12\x37\n\x08workflow\x18\x01 \x01(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08workflow"8\n\x15\x44\x65leteWorkflowRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId"C\n\x16\x44\x65leteWorkflowResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status"S\n\x14ListWorkflowsRequest\x12;\n\npagination\x18\x01 \x01(\x0b\x32\x1b.common.v2.PaginationParamsR\npagination"\x8f\x01\n\x15ListWorkflowsResponse\x12\x39\n\tworkflows\x18\x01 \x03(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\tworkflows\x12;\n\npagination\x18\x02 \x01(\x0b\x32\x1b.common.v2.PaginationResultR\npagination">\n\x1bListWorkflowVersionsRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId"W\n\x1cListWorkflowVersionsResponse\x12\x37\n\x08versions\x18\x01 \x03(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08versions2\xc5\x04\n\x0fWorkflowService\x12[\n\x0e\x43reateWorkflow\x12".workflow.v2.CreateWorkflowRequest\x1a#.workflow.v2.CreateWorkflowResponse"\x00\x12R\n\x0bGetWorkflow\x12\x1f.workflow.v2.GetWorkflowRequest\x1a .workflow.v2.GetWorkflowResponse"\x00\x12[\n\x0eUpdateWorkflow\x12".workflow.v2.UpdateWorkflowRequest\x1a#.workflow.v2.UpdateWorkflowResponse"\x00\x12[\n\x0e\x44\x65leteWorkflow\x12".workflow.v2.DeleteWorkflowRequest\x1a#.workflow.v2.DeleteWorkflowResponse"\x00\x12X\n\rListWorkflows\x12!.workflow.v2.ListWorkflowsRequest\x1a".workflow.v2.ListWorkflowsResponse"\x00\x12m\n\x14ListWorkflowVersions\x12(.workflow.v2.ListWorkflowVersionsRequest\x1a).workflow.v2.ListWorkflowVersionsResponse"\x00\x42\xb8\x01\n\x0f\x63om.workflow.v2B\x14WorkflowServiceProtoP\x01ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\xa2\x02\x03WXX\xaa\x02\x0bWorkflow.V2\xca\x02\x0bWorkflow\\V2\xe2\x02\x17Workflow\\V2\\GPBMetadata\xea\x02\x0cWorkflow::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "workflow.v2.workflow_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\017com.workflow.v2B\024WorkflowServiceProtoP\001ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\242\002\003WXX\252\002\013Workflow.V2\312\002\013Workflow\\V2\342\002\027Workflow\\V2\\GPBMetadata\352\002\014Workflow::V2"
    _globals["_CREATEWORKFLOWREQUEST"]._serialized_start = 138
    _globals["_CREATEWORKFLOWREQUEST"]._serialized_end = 285
    _globals["_CREATEWORKFLOWRESPONSE"]._serialized_start = 287
    _globals["_CREATEWORKFLOWRESPONSE"]._serialized_end = 368
    _globals["_GETWORKFLOWREQUEST"]._serialized_start = 370
    _globals["_GETWORKFLOWREQUEST"]._serialized_end = 466
    _globals["_GETWORKFLOWRESPONSE"]._serialized_start = 468
    _globals["_GETWORKFLOWRESPONSE"]._serialized_end = 546
    _globals["_UPDATEWORKFLOWREQUEST"]._serialized_start = 549
    _globals["_UPDATEWORKFLOWREQUEST"]._serialized_end = 790
    _globals["_UPDATEWORKFLOWRESPONSE"]._serialized_start = 792
    _globals["_UPDATEWORKFLOWRESPONSE"]._serialized_end = 873
    _globals["_DELETEWORKFLOWREQUEST"]._serialized_start = 875
    _globals["_DELETEWORKFLOWREQUEST"]._serialized_end = 931
    _globals["_DELETEWORKFLOWRESPONSE"]._serialized_start = 933
    _globals["_DELETEWORKFLOWRESPONSE"]._serialized_end = 1000
    _globals["_LISTWORKFLOWSREQUEST"]._serialized_start = 1002
    _globals["_LISTWORKFLOWSREQUEST"]._serialized_end = 1085
    _globals["_LISTWORKFLOWSRESPONSE"]._serialized_start = 1088
    _globals["_LISTWORKFLOWSRESPONSE"]._serialized_end = 1231
    _globals["_LISTWORKFLOWVERSIONSREQUEST"]._serialized_start = 1233
    _globals["_LISTWORKFLOWVERSIONSREQUEST"]._serialized_end = 1295
    _globals["_LISTWORKFLOWVERSIONSRESPONSE"]._serialized_start = 1297
    _globals["_LISTWORKFLOWVERSIONSRESPONSE"]._serialized_end = 1384
    _globals["_WORKFLOWSERVICE"]._serialized_start = 1387
    _globals["_WORKFLOWSERVICE"]._serialized_end = 1968
# @@protoc_insertion_point(module_scope)



# Auto-generated __init__.py
from . import api
from . import bytestream
from . import geo
from . import longrunning
from . import rpc
from . import type

__all__ = ["api", "bytestream", "geo", "longrunning", "rpc", "type"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: llm/v2/llm.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "llm/v2/llm.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x10llm/v2/llm.proto\x12\x06llm.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto"n\n\x07Message\x12\'\n\x04role\x18\x01 \x01(\x0e\x32\x13.llm.v2.MessageRoleR\x04role\x12\x18\n\x07\x63ontent\x18\x02 \x01(\tR\x07\x63ontent\x12\x17\n\x04name\x18\x03 \x01(\tH\x00R\x04name\x88\x01\x01\x42\x07\n\x05_name"u\n\x04Tool\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x37\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\nparameters"L\n\x08ToolCall\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1c\n\targuments\x18\x03 \x01(\tR\targuments"\xef\x01\n\x10GenerationParams\x12%\n\x0btemperature\x18\x01 \x01(\x02H\x00R\x0btemperature\x88\x01\x01\x12\x18\n\x05top_p\x18\x02 \x01(\x02H\x01R\x04topP\x88\x01\x01\x12"\n\nmax_tokens\x18\x03 \x01(\x05H\x02R\tmaxTokens\x88\x01\x01\x12%\n\x0estop_sequences\x18\x04 \x03(\tR\rstopSequences\x12\x1b\n\x06stream\x18\x05 \x01(\x08H\x03R\x06stream\x88\x01\x01\x42\x0e\n\x0c_temperatureB\x08\n\x06_top_pB\r\n\x0b_max_tokensB\t\n\x07_stream"\x81\x01\n\nTokenUsage\x12#\n\rprompt_tokens\x18\x01 \x01(\x05R\x0cpromptTokens\x12+\n\x11\x63ompletion_tokens\x18\x02 \x01(\x05R\x10\x63ompletionTokens\x12!\n\x0ctotal_tokens\x18\x03 \x01(\x05R\x0btotalTokens"\x9d\x02\n\x13GenerateTextRequest\x12,\n\x08provider\x18\x01 \x01(\x0e\x32\x10.llm.v2.ProviderR\x08provider\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12+\n\x08messages\x18\x03 \x03(\x0b\x32\x0f.llm.v2.MessageR\x08messages\x12\x35\n\x06params\x18\x04 \x01(\x0b\x32\x18.llm.v2.GenerationParamsH\x00R\x06params\x88\x01\x01\x12"\n\x05tools\x18\x05 \x03(\x0b\x32\x0c.llm.v2.ToolR\x05tools\x12/\n\x08metadata\x18\x06 \x01(\x0b\x32\x13.common.v2.MetadataR\x08metadataB\t\n\x07_params"\x8c\x02\n\x14GenerateTextResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12:\n\x10response_message\x18\x02 \x01(\x0b\x32\x0f.llm.v2.MessageR\x0fresponseMessage\x12/\n\ntool_calls\x18\x03 \x03(\x0b\x32\x10.llm.v2.ToolCallR\ttoolCalls\x12-\n\x05usage\x18\x04 \x01(\x0b\x32\x12.llm.v2.TokenUsageH\x00R\x05usage\x88\x01\x01\x12#\n\rfinish_reason\x18\x05 \x01(\tR\x0c\x66inishReasonB\x08\n\x06_usage"R\n\x19GenerateTextStreamRequest\x12\x35\n\x07request\x18\x01 \x01(\x0b\x32\x1b.llm.v2.GenerateTextRequestR\x07request"\xed\x01\n\x1aGenerateTextStreamResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12\x14\n\x05\x64\x65lta\x18\x02 \x01(\tR\x05\x64\x65lta\x12-\n\x05usage\x18\x03 \x01(\x0b\x32\x12.llm.v2.TokenUsageH\x00R\x05usage\x88\x01\x01\x12(\n\rfinish_reason\x18\x04 \x01(\tH\x01R\x0c\x66inishReason\x88\x01\x01\x12\x19\n\x08is_final\x18\x05 \x01(\x08R\x07isFinalB\x08\n\x06_usageB\x10\n\x0e_finish_reason"\xa5\x01\n\x18GenerateEmbeddingRequest\x12,\n\x08provider\x18\x01 \x01(\x0e\x32\x10.llm.v2.ProviderR\x08provider\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12\x14\n\x05texts\x18\x03 \x03(\tR\x05texts\x12/\n\x08metadata\x18\x04 \x01(\x0b\x32\x13.common.v2.MetadataR\x08metadata"A\n\tEmbedding\x12\x16\n\x06values\x18\x01 \x03(\x02R\x06values\x12\x1c\n\tdimension\x18\x02 \x01(\x05R\tdimension"\xb2\x01\n\x19GenerateEmbeddingResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12\x31\n\nembeddings\x18\x02 \x03(\x0b\x32\x11.llm.v2.EmbeddingR\nembeddings\x12-\n\x05usage\x18\x03 \x01(\x0b\x32\x12.llm.v2.TokenUsageH\x00R\x05usage\x88\x01\x01\x42\x08\n\x06_usage*\xab\x01\n\x08Provider\x12\x18\n\x14PROVIDER_UNSPECIFIED\x10\x00\x12\x13\n\x0fPROVIDER_OPENAI\x10\x01\x12\x16\n\x12PROVIDER_ANTHROPIC\x10\x02\x12\x13\n\x0fPROVIDER_GOOGLE\x10\x03\x12\x19\n\x15PROVIDER_AZURE_OPENAI\x10\x04\x12\x13\n\x0fPROVIDER_COHERE\x10\x05\x12\x13\n\x0fPROVIDER_OLLAMA\x10\x06*\x8e\x01\n\x0bMessageRole\x12\x1c\n\x18MESSAGE_ROLE_UNSPECIFIED\x10\x00\x12\x17\n\x13MESSAGE_ROLE_SYSTEM\x10\x01\x12\x15\n\x11MESSAGE_ROLE_USER\x10\x02\x12\x1a\n\x16MESSAGE_ROLE_ASSISTANT\x10\x03\x12\x15\n\x11MESSAGE_ROLE_TOOL\x10\x04\x32\x9e\x02\n\x12LLMProviderService\x12K\n\x0cGenerateText\x12\x1b.llm.v2.GenerateTextRequest\x1a\x1c.llm.v2.GenerateTextResponse"\x00\x12_\n\x12GenerateTextStream\x12!.llm.v2.GenerateTextStreamRequest\x1a".llm.v2.GenerateTextStreamResponse"\x00\x30\x01\x12Z\n\x11GenerateEmbedding\x12 .llm.v2.GenerateEmbeddingRequest\x1a!.llm.v2.GenerateEmbeddingResponse"\x00\x42\x89\x01\n\ncom.llm.v2B\x08LlmProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/llm/v2;llmv2\xa2\x02\x03LXX\xaa\x02\x06Llm.V2\xca\x02\x06Llm\\V2\xe2\x02\x12Llm\\V2\\GPBMetadata\xea\x02\x07Llm::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "llm.v2.llm_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\ncom.llm.v2B\010LlmProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/llm/v2;llmv2\242\002\003LXX\252\002\006Llm.V2\312\002\006Llm\\V2\342\002\022Llm\\V2\\GPBMetadata\352\002\007Llm::V2"
    _globals["_PROVIDER"]._serialized_start = 2065
    _globals["_PROVIDER"]._serialized_end = 2236
    _globals["_MESSAGEROLE"]._serialized_start = 2239
    _globals["_MESSAGEROLE"]._serialized_end = 2381
    _globals["_MESSAGE"]._serialized_start = 82
    _globals["_MESSAGE"]._serialized_end = 192
    _globals["_TOOL"]._serialized_start = 194
    _globals["_TOOL"]._serialized_end = 311
    _globals["_TOOLCALL"]._serialized_start = 313
    _globals["_TOOLCALL"]._serialized_end = 389
    _globals["_GENERATIONPARAMS"]._serialized_start = 392
    _globals["_GENERATIONPARAMS"]._serialized_end = 631
    _globals["_TOKENUSAGE"]._serialized_start = 634
    _globals["_TOKENUSAGE"]._serialized_end = 763
    _globals["_GENERATETEXTREQUEST"]._serialized_start = 766
    _globals["_GENERATETEXTREQUEST"]._serialized_end = 1051
    _globals["_GENERATETEXTRESPONSE"]._serialized_start = 1054
    _globals["_GENERATETEXTRESPONSE"]._serialized_end = 1322
    _globals["_GENERATETEXTSTREAMREQUEST"]._serialized_start = 1324
    _globals["_GENERATETEXTSTREAMREQUEST"]._serialized_end = 1406
    _globals["_GENERATETEXTSTREAMRESPONSE"]._serialized_start = 1409
    _globals["_GENERATETEXTSTREAMRESPONSE"]._serialized_end = 1646
    _globals["_GENERATEEMBEDDINGREQUEST"]._serialized_start = 1649
    _globals["_GENERATEEMBEDDINGREQUEST"]._serialized_end = 1814
    _globals["_EMBEDDING"]._serialized_start = 1816
    _globals["_EMBEDDING"]._serialized_end = 1881
    _globals["_GENERATEEMBEDDINGRESPONSE"]._serialized_start = 1884
    _globals["_GENERATEEMBEDDINGRESPONSE"]._serialized_end = 2062
    _globals["_LLMPROVIDERSERVICE"]._serialized_start = 2384
    _globals["_LLMPROVIDERSERVICE"]._serialized_end = 2670
# @@protoc_insertion_point(module_scope)
